# Utils Package

This repo contains some useful helper function for Python

## Installation

Install this package using

```
pip install utils-package-Martin36
```

## Development
If you want to help make this package better, feel free to put up a Pull Request. 
### Run tests
In order to run the test suite, run the following:
```
PYTHONPATH=src python tests/test_util_funcs.py
```

